local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local _

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.StatBuffs = {
	1126--[[Mark of the Wild]],
	115921--[[Legacy of the Emperor]],
	20217--[[Blessing of Kings]],
	90363--[[Embrace of the Shale Spider]]
}

a.CritBuffs = {
	116781--[[Legacy of the White Tiger]],
	17007--[[Leader of the Pack]],
	1459--[[Arcane Brilliance]],
	61316--[[Dalaran Brilliance]],
	97229--[[Bellowing Roar]],
	24604--[[Furious Howl]],
	90309--[[Terrifying Roar]],
	126373--[[Fearless Roar]],
	126309--[[Still Water]],
}

a.spells["Auto Attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = true,
	Melee = true,
	NotIfActive = 1,
	Check = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Potion with Bloodlust or TTD <= 60"] = {
	Type = "item",
	ID = 76089--[[Virmen's Bite]],
	Buff = {105697--[[Virmen's Bite]], 79633--[[Potion of the Tol'vir]]},
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.ActiveEnemy and s.Boss("target")
	end,
	CheckLast = function(z)
		return x.Bloodlust or (x.TimeToDie <= 60)
	end,
	FlashID = {76089--[[Virmen's Bite]], 58145--[[Potion of the Tol'vir]]},
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["Purify Moderate Stagger"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	RequireDebuff = 124274--[[Moderate Stagger]],
	RequireBuffUnit = "player", 
}

a.spells["Purify Heavy Stagger"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Red",
	RequireDebuff = 124273--[[Heavy Stagger]],
	RequireBuffUnit = "player", 
}

a.spells["Rushing Jade Wind (Brewmaster)"] = {
	ID = 116847--[[Rushing Jade Wind]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	EarlyRefresh = 4,
	Check = function(z)
		return x.NoCC
	end,
	Continue = true,
}

a.spells["Blackout Kick (Brewmaster)"] = {
	ID = 100784--[[Blackout Kick]],
	Buff = 115307--[[Shuffle]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	EarlyRefresh = 4,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["Tiger's Lust"] = {
	ID = 116841--[[Tiger's Lust]],
	NoRangeCheck = true,
	Check = function(z)
		return s.HasTalent(116841--[[Tiger's Lust]]) and s.MovementImpaired("player", 1, false, true) == 1
	end,
}

a.spells["Chi Wave"] = {
	ID = 115098--[[Chi Wave]],
	Check = function(z)
		return s.HasTalent(115098--[[Chi Wave]]) and a.specCheck()
	end,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["Zen Sphere"] = {
	ID = 124081--[[Zen Sphere]],
	NoRangeCheck = true,
	Unit = "player",
	Check = function(z)
		return s.HasTalent(124081--[[Zen Sphere]]) and a.specCheck()
	end,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["Chi Burst"] = {
	ID = 123986--[[Chi Burst]],
	NoRangeCheck = true,
	Check = function(z)
		return s.HasTalent(123986--[[Chi Burst]]) and a.specCheck()
	end,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["Chi Brew"] = {
	ID = 115399--[[Chi Brew]],
	NoRangeCheck = true,
	Check = function(z)
		return s.HasTalent(115399--[[Chi Brew]]) and x.Chi == 0
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["Charging Ox Wave"] = {
	ID = 119392--[[Charging Ox Wave]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(119392--[[Charging Ox Wave]]) and not s.MeleeDistance("target")
	end,
	FlashColor = "Pink",
}

a.spells["Dampen Harm"] = {
	ID = 122278--[[Dampen Harm]],
	Check = function(z)
		return s.HasTalent(122278--[[Dampen Harm]]) and s.HealthPercent("player") < 50 and x.ShouldTemporaryBuff
	end,
	FlashColor = "Red",
}

a.spells["Diffuse Magic"] = {
	ID = 122783--[[Diffuse Magic]],
	Check = function(z)
		return s.HasTalent(122783--[[Diffuse Magic]]) and s.HealthPercent("player") < 50 and x.ShouldTemporaryBuff
	end,
	FlashColor = "Red",
}

a.spells["Rushing Jade Wind"] = {
	ID = 116847--[[Rushing Jade Wind]],
	NoRangeCheck = true,
	Check = function(z)
		return s.HasTalent(116847--[[Rushing Jade Wind]]) and a.specCheck()
	end,
	FlashColor = "Pink",
	Continue = true,
}

a.spells["Invoke Xuen, the White Tiger"] = {
	ID = 123904--[[Invoke Xuen, the White Tiger]],
	NoRangeCheck = true,
	Check = function(z)
		return x.NoCC and s.HasTalent(123904--[[Invoke Xuen, the White Tiger]]) 
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["Breath of Fire"] = {
	ID = 115181--[[Breath of Fire]],
	MyDebuff = 115181--[[Breath of Fire]],
	RequireDebuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and a.keepupShuffle()
	end,
	FlashColor = Purple,
	Continue = true,
}

a.spells["Rising Sun Kick (Debuff)"] = {
	ID = 107428--[[Rising Sun Kick]],
	MyDebuff = 130320--[[Rising Sun Kick]],
	EarlyRefresh = 3,
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["Rising Sun Kick"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["Fists of Fury"] = {
	ID = 113656--[[Fists of Fury]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoRangeCheck = true,
	Check = function(z)
		return x.NoCC and x.TimeToMax > x.FoFCast and s.BuffDuration(125359--[[Tiger Power]], "player") > x.FoFCast
	end,
}

a.spells["Energizing Brew"] = {
	ID = 115288--[[Energizing Brew]],
	Check = function(z)
		return x.ShouldTemporaryBuff and x.TimeToMax > 5
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["Spinning Crane Kick (Brewmaster)"] = {
	ID = 101546--[[Spinning Crane Kick]],
	FlashColor = "Purple",
	Check = function(z)
		return (x.ShuffleDuration > 4 and x.Chi == 0) or (x.ShuffleDuration > 3 and x.Chi > 0)
	end,
	Continue = true,
}

a.spells["Keg Smash"] = {
	ID = 121253--[[Keg Smash]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi <= (x.MaxChi - 2)
	end,
}

a.spells["Expel Harm (Brewmaster)"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Check = function(z)
		return s.HealthPercent("player") < 80
	end,
}

a.spells["Expel Harm (Windwalker)"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Check = function(z)
		return s.HealthPercent("player") < 80 and x.Chi <= (x.MaxChi - 2) 
	end,
--	FlashColor = "Pink",
	Continue = true,
}

a.spells["Flying Serpent Kick"] = {
	ID = 101545--[[Flying Serpent Kick]],
--	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and not s.MeleeDistance("target")
	end,
	FlashColor = "Pink",
}

a.spells["Jab (Brewmaster)"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi <= (x.MaxChi - s.If(s.Buff(129914--[[Power Strikes]], "player"), 2, 1)) and x.Energy >= 40
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["Jab (Windwalker)"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.Chi <= (x.MaxChi - s.If(s.Buff(129914--[[Power Strikes]], "player"), 3, 2)) and x.Energy >= 40
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["Guard"] = {
	ID = 115295--[[Guard]],
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return s.HealthPercent("player") < 75 and x.ShouldTemporaryBuff
	end,
}

a.spells["Tiger Palm (Brewmaster)"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.ShuffleDuration > 1
	end,
}

a.spells["Combo Breaker: Tiger Palm"] = {
	ID = 100787--[[Tiger Palm]],
	RequireBuff =  118864--[[Combo Breaker: Tiger Palm]],
	RequireBuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.NoCC and x.TimeToMax >= 2
	end,
}

a.spells["Combo Breaker: Blackout Kick"] = {
	ID = 100784--[[Blackout Kick]],
	RequireBuff =  116768--[[Combo Breaker: Blackout Kick]],
	RequireBuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.NoCC
	end,
}

a.spells["Blackout Kick w/ time to max energy <= 2"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and x.TimeToMax <= 2 and x.Chi >= (x.MaxChi - 1)
	end,
}

a.spells["Blackout Kick at max Chi"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.NoCC and (((x.Energy + (x.EnergyPerSecond * s.SpellCooldown(107428--[[Rising Sun Kick]]))) >= 40) or x.Chi == x.MaxChi)
	end,
}

a.spells["Tigereye Brew"] = {
	ID = 116740--[[Tigereye Brew]],
	RequireBuff = 125195--[[Tigereye Brew]],
	RequireBuffUnit = "player",
	RequireStack = 10,
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return x.NoCC and x.ShouldTemporaryBuff
	end,
}

a.spells["Tiger Palm (Buff)"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	EarlyRefresh = 3,
	Check = function(z)
		return x.NoCC and x.Chi > 0
	end,
}

a.spells["Elusive Brew"] = {
	ID = 115308--[[Elusive Brew]],
	Check = function(z)
		return s.MyBuffStack(115308--[[Elusive Brew]], "player") >= 3 and x.ShouldTemporaryBuff
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Fortifying Brew"] = {
	ID = 115203--[[Fortifying Brew]],
	FlashColor = "Red",
	Check = function(z)
		return s.HealthPercent("player") < 50 and x.ShouldTemporaryBuff
	end,
	NoGCD = true,
}

a.spells["Stance of the Sturdy Ox"] = {
	Type = "form",
	ID = 115069--[[Stance of the Sturdy Ox]],
	Buff = 115069--[[Stance of the Sturdy Ox]],
	BuffUnit = "player",
	FlashColor = "Green",
}

a.spells["Stance of the Fierce Tiger"] = {
	Type = "form",
	ID = 103985--[[Stance of the Fierce Tiger]],
	Buff = 103985--[[Stance of the Fierce Tiger]],
	BuffUnit = "player",
	FlashColor = "Green",
}

a.spells["Stance of the Wise Serpent"] = {
	Type = "form",
	ID = 115070--[[Stance of the Wise Serpent]],
	Buff = 115070--[[Stance of the Wise Serpent]],
	BuffUnit = "player",
	FlashColor = "Green",
}

a.spells["Legacy of the Emperor"] = {
	ID = 115921--[[Legacy of the Emperor]],
	Buff = a.StatBuffs,
	EarlyRefresh = 10,
	NoRangeCheck = true,
	BuffUnit = "raid",
	FlashColor = "Green",
}

a.spells["Legacy of the White Tiger"] = {
	ID = 116781--[[Legacy of the White Tiger]],
	Buff = a.CritBuffs,
	EarlyRefresh = 10,
	NoRangeCheck = true,
	BuffUnit = "raid",
	FlashColor = "Green",
}

a.spells["Spear Hand Strike"] = {
	ID = 116705--[[Spear Hand Strike]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["Paralysis"] = {
	ID = 115078--[[Paralysis]],
	EnemyTargetNeeded = true,
	Interrupt = 1,
	Check = function(z)
		return not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["Leg Sweep"] = {
	ID = 119381--[[Leg Sweep]],
	EnemyTargetNeeded = true,
	Interrupt = 1,
	Check = function(z)
		return s.HasTalent(119381--[[Leg Sweep]]) and not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["Provoke"] = {
	ID = 115546--[[Provoke]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.Form(115069--[[Stance of the Sturdy Ox]]) and x.NoCC and x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.InCombat
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["Clash"] = {
	ID = 122057--[[Clash]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Roll"] = {
	ID = 109132--[[Roll]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.NoCC and not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Dizzying Haze"] = {
	ID = 115180--[[Dizzying Haze]],
	Debuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = true,
	NoRangeCheck = true,
	FlashColor = "Blue",
}